diff --git a/libpurple/purpleaddcontactrequest.h b/libpurple/purpleaddcontactrequest.h
--- a/libpurple/purpleaddcontactrequest.h
+++ b/libpurple/purpleaddcontactrequest.h
@@ -72,10 +72,10 @@ PurpleAddContactRequest *purple_add_cont
 PurpleAccount *purple_add_contact_request_get_account(PurpleAddContactRequest *request);
 
 /**
- * purple_add_contact_request_get_remote_username:
+ * purple_add_contact_request_get_username:
  * @request: The instance.
  *
- * Gets the username for the user requesting authorization.
+ * Gets the username for the user to be added.
  *
  * Returns: The username of the remote user.
  *
# HG changeset patch
# Node ID 6167aa9f2e31
# Parent  d8636f8db50a
diff --git a/libpurple/purpleauthorizationrequest.h b/libpurple/purpleauthorizationrequest.h
--- a/libpurple/purpleauthorizationrequest.h
+++ b/libpurple/purpleauthorizationrequest.h
@@ -73,7 +73,7 @@ PurpleAuthorizationRequest *purple_autho
 PurpleAccount *purple_authorization_request_get_account(PurpleAuthorizationRequest *request);
 
 /**
- * purple_authorization_request_get_remote_username:
+ * purple_authorization_request_get_username:
  * @request: The instance.
  *
  * Gets the username for the user requesting authorization.
diff --git a/libpurple/purpleauthorizationrequest.c b/libpurple/purpleauthorizationrequest.c
--- a/libpurple/purpleauthorizationrequest.c
+++ b/libpurple/purpleauthorizationrequest.c
@@ -227,7 +227,7 @@ purple_authorization_request_class_init(
 		G_TYPE_STRING);
 
 	/**
-	 * PurpleAuthorizationRequest:account: (attributes org.gtk.Property.get=purple_authorization_request_get_account)
+	 * PurpleAuthorizationRequest:account:
 	 *
 	 * The account that this authorization request is for.
 	 *
@@ -240,33 +240,33 @@ purple_authorization_request_class_init(
 		G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
 	/**
-	 * PurpleAuthorizationRequest:username: (attributes org.gtk.Property.get=purple_authorization_request_get_username):
+	 * PurpleAuthorizationRequest:username:
 	 *
-	 * The username of the remote user requesting authorization.
+	 * The username of the remote user that is requesting authorization.
 	 *
 	 * Since: 3.0.0
 	 */
 	properties[PROP_USERNAME] = g_param_spec_string(
 		"username", "username",
-		"The username of the remote user requesting authorization",
+		"The username of the remote user that is requesting authorization",
 		NULL,
 		G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
 	/**
-	 * PurpleAuthorizationRequest:alias: (attributes org.gtk.Property.get=purple_authorization_request_get_alias org.gtk.Property.set=purple_authorization_request_set_alias)
+	 * PurpleAuthorizationRequest:alias:
 	 *
-	 * The alias of the remote user request authorization.
+	 * The alias of the remote user that is requesting authorization.
 	 *
 	 * Since: 3.0.0
 	 */
 	properties[PROP_ALIAS] = g_param_spec_string(
 		"alias", "alias",
-		"The alias of the remote user request authorization",
+		"The alias of the remote user that is requesting authorization",
 		NULL,
 		G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	/**
-	 * PurpleAuthorizationRequest:message: (attributes org.gtk.Property.get=purple_authorization_request_get_message org.gtk.Property.set=purple_authorization_request_set_message)
+	 * PurpleAuthorizationRequest:message:
 	 *
 	 * The optional message sent from the remote user.
 	 *

diff --git a/libpurple/purpleaddcontactrequest.c b/libpurple/purpleaddcontactrequest.c
--- a/libpurple/purpleaddcontactrequest.c
+++ b/libpurple/purpleaddcontactrequest.c
@@ -195,9 +195,9 @@ purple_add_contact_request_class_init(Pu
 		0);
 
 	/**
-	 * PurpleAddContactRequest:account: (attributes org.gtk.Property.get=purple_add_contact_request_get_account)
+	 * PurpleAddContactRequest:account:
 	 *
-	 * The account that this authorization request is for.
+	 * The account that this add contact request is for.
 	 *
 	 * Since: 3.0.0
 	 */
@@ -208,33 +208,33 @@ purple_add_contact_request_class_init(Pu
 		G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
 	/**
-	 * PurpleAddContactRequest:username: (attributes org.gtk.Property.get=purple_add_contact_request_get_username):
+	 * PurpleAddContactRequest:username:
 	 *
 	 * The username of the remote user requesting authorization.
 	 *
 	 * Since: 3.0.0
 	 */
 	properties[PROP_USERNAME] = g_param_spec_string(
 		"username", "username",
-		"The username of the remote user requesting authorization",
+		"The username of the remote user to be added.",
 		NULL,
 		G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
 	/**
-	 * PurpleAddContactRequest:alias: (attributes org.gtk.Property.get=purple_add_contact_request_get_alias org.gtk.Property.set=purple_add_contact_request_set_alias)
+	 * PurpleAddContactRequest:alias:
 	 *
 	 * The alias of the remote user request authorization.
 	 *
 	 * Since: 3.0.0
 	 */
 	properties[PROP_ALIAS] = g_param_spec_string(
 		"alias", "alias",
-		"The alias of the remote user request authorization",
+		"The alias of the remote user to be added.",
 		NULL,
 		G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	/**
-	 * PurpleAddContactRequest:message: (attributes org.gtk.Property.get=purple_add_contact_request_get_message org.gtk.Property.set=purple_add_contact_request_set_message)
+	 * PurpleAddContactRequest:message:
 	 *
 	 * The optional message sent from the remote user.
 	 *
@@ -208,33 +208,33 @@ purple_add_contact_request_class_init(Pu
 	 *
-	 * The username of the remote user requesting authorization.
+	 * The username of the remote user to be added.
 	 *
 	 * Since: 3.0.0
@@ -208,33 +208,33 @@ purple_add_contact_request_class_init(Pu
 	 *
-	 * The alias of the remote user request authorization.
+	 * The alias of the remote user to be added.
 	 *
 	 * Since: 3.0.0